Class: Yes::Core::Aggregate::Dsl::AttributeDefiners::Standard
- Inherits:
-
Object
- Object
- Yes::Core::Aggregate::Dsl::AttributeDefiners::Standard
- Defined in:
- lib/yes/core/aggregate/dsl/attribute_definers/standard.rb
Overview
Handles the definition and generation of standard attribute-related classes and methods
Instance Method Summary collapse
-
#call { ... } ⇒ void
Generates and registers all necessary classes for the attribute.
-
#initialize(attribute_data) ⇒ Base
constructor
Initializes a new Base instance.
Constructor Details
#initialize(attribute_data) ⇒ Base
Initializes a new Base instance
19 20 21 |
# File 'lib/yes/core/aggregate/dsl/attribute_definers/standard.rb', line 19 def initialize(attribute_data) @attribute_data = attribute_data end |
Instance Method Details
#call { ... } ⇒ void
This method returns an undefined value.
Generates and registers all necessary classes for the attribute.
28 29 30 |
# File 'lib/yes/core/aggregate/dsl/attribute_definers/standard.rb', line 28 def call MethodDefiners::Attribute::Accessor.new(attribute_data).call end |