Module: Yes::Core::Aggregate::HasAuthorizer

Extended by:
ActiveSupport::Concern
Included in:
Yes::Core::Aggregate
Defined in:
lib/yes/core/aggregate/has_authorizer.rb

Overview

Provides authorizer functionality for aggregates.

This concern automatically sets up an authorizer class for the aggregate using ‘Yes::Core::Aggregate::Dsl::ClassResolvers::Authorizer`. The authorizer class is typically used for command authorization via Cerbos.

Since:

  • 0.1.0

Defined Under Namespace

Classes: AuthorizerOptions