Class: Yes::Core::Aggregate::Dsl::AttributeDefiner
- Inherits:
-
Object
- Object
- Yes::Core::Aggregate::Dsl::AttributeDefiner
- Defined in:
- lib/yes/core/aggregate/dsl/attribute_definer.rb
Overview
Factory class that creates the appropriate attribute definer based on the attribute type
Instance Method Summary collapse
-
#call { ... } ⇒ void
Creates the appropriate definer and calls it to generate the necessary classes and methods.
-
#initialize(attribute_data) ⇒ AttributeDefiner
constructor
Initializes a new AttributeDefiner instance.
Constructor Details
#initialize(attribute_data) ⇒ AttributeDefiner
Initializes a new AttributeDefiner instance
26 27 28 |
# File 'lib/yes/core/aggregate/dsl/attribute_definer.rb', line 26 def initialize(attribute_data) @attribute_data = attribute_data end |
Instance Method Details
#call { ... } ⇒ void
This method returns an undefined value.
Creates the appropriate definer and calls it to generate the necessary classes and methods
35 36 37 |
# File 'lib/yes/core/aggregate/dsl/attribute_definer.rb', line 35 def call(&) definer_for_type.new(attribute_data).call(&) end |