Class: Yes::Core::Aggregate::Dsl::ClassResolvers::Base Abstract
- Inherits:
-
Object
- Object
- Yes::Core::Aggregate::Dsl::ClassResolvers::Base
- Defined in:
- lib/yes/core/aggregate/dsl/class_resolvers/base.rb
Overview
This class is abstract.
Subclass and override #class_type, #class_name, and #generate_class
Base class for creating and registering aggregate-related classes
This class provides the foundation for resolving and generating various aggregate-related classes such as commands, events, and handlers. It handles class registration and provides a template for class generation.
to implement specific class resolver behavior
Direct Known Subclasses
Authorizer, Command::Base, ReadModel, ReadModelFilter, ReadModelSerializer
Instance Method Summary collapse
-
#call ⇒ Class
Creates and registers the class in the Yes::Core configuration.
Instance Method Details
#call ⇒ Class
Creates and registers the class in the Yes::Core configuration
20 21 22 23 24 25 26 27 28 |
# File 'lib/yes/core/aggregate/dsl/class_resolvers/base.rb', line 20 def call Yes::Core.configuration.register_aggregate_class( context_name, aggregate_name, class_name, class_type, find_or_generate_class ) end |