Exception: Yes::Core::CommandHandling::ConcurrentUpdateError
- Inherits:
-
Error
- Object
- StandardError
- Error
- Yes::Core::CommandHandling::ConcurrentUpdateError
- Defined in:
- lib/yes/core/command_handling/command_executor.rb
Overview
Raised when multiple processes attempt to update the same aggregate concurrently This error is thrown when the pending_update_since mechanism detects a conflict
Instance Attribute Summary
Attributes inherited from Error
Instance Method Summary collapse
-
#initialize(aggregate_class:, aggregate_id:, original_error: nil) ⇒ ConcurrentUpdateError
constructor
Initializes a new ConcurrentUpdateError.
Constructor Details
#initialize(aggregate_class:, aggregate_id:, original_error: nil) ⇒ ConcurrentUpdateError
Initializes a new ConcurrentUpdateError
14 15 16 17 18 19 20 21 22 23 24 |
# File 'lib/yes/core/command_handling/command_executor.rb', line 14 def initialize(aggregate_class:, aggregate_id:, original_error: nil) = (aggregate_class, aggregate_id, original_error) super(, extra: { aggregate_class: aggregate_class.name, aggregate_id: aggregate_id, context: aggregate_class.context, stream_name: aggregate_class.aggregate, original_error: original_error&. }) end |